pitchtools.list_inversion_equivalent_chromatic_interval_classes_pairwise
========================================================================

.. autofunction:: abjad.tools.pitchtools.list_inversion_equivalent_chromatic_interval_classes_pairwise.list_inversion_equivalent_chromatic_interval_classes_pairwise
   :noindex:
